@@ -1,19 +1,22 @@
-# Fortify spatial polygons and lines
-# Fortify method for a number of the class from the sp package.
-# 
-# To figure out the correct variable name for region, inspect 
-# \code{as.data.frame(model)}.
-# 
-# @alias fortify.SpatialPolygons
-# @alias fortify.Polygons
-# @alias fortify.Polygon
-# @alias fortify.SpatialLinesDataFrame
-# @alias fortify.Lines
-# @alias fortify.Line
-# @arguments SpatialPolygonsDataFrame
-# @arguments not used
-# @arguments name of variable to split up regions by
-# @arguments not used
+#' Fortify method for classes from the sp package.
+#' 
+#' To figure out the correct variable name for region, inspect 
+#' \code{as.data.frame(model)}.
+#' 
+#' @S3method fortify SpatialPolygons
+#' @S3method fortify SpatialPolygonsDataFrame
+#' @S3method fortify Polygons
+#' @S3method fortify Polygon
+#' @S3method fortify SpatialLinesDataFrame
+#' @S3method fortify Lines
+#' @S3method fortify Line
+#' @param model \code{SpatialPolygonsDataFrame} to convert into a dataframe.
+#' @param data not used by this method
+#' @param region name of variable used to split up regions
+#' @param ... not used by this method
+#' @name fortify.sp
+NULL
+
 fortify.SpatialPolygonsDataFrame <- function(model, data, region = NULL, ...) {
   attr <- as.data.frame(model)
   # If not specified, split into regions based on first variable in attributes
@@ -37,12 +40,12 @@ fortify.SpatialPolygonsDataFrame <- function(model, data, region = NULL, ...) {
 }
 
 fortify.SpatialPolygons <- function(model, data, ...) {
-  plyr::ldply(model@polygons, fortify)
+  ldply(model@polygons, fortify)
 }
 
 fortify.Polygons <- function(model, data, ...) {
   subpolys <- model@Polygons
-  pieces <- plyr::ldply(seq_along(subpolys), function(i) {
+  pieces <- ldply(seq_along(subpolys), function(i) {
     df <- fortify(subpolys[[model@plotOrder[i]]])
     df$piece <- i
     df
@@ -65,12 +68,12 @@ fortify.Polygon <- function(model, data, ...) {
 }
 
 fortify.SpatialLinesDataFrame <- function(model, data, ...) {
-  plyr::ldply(model@lines, fortify)
+  ldply(model@lines, fortify)
 }
 
 fortify.Lines <- function(model, data, ...) {
   lines <- model@Lines
-  pieces <- plyr::ldply(seq_along(lines), function(i) {
+  pieces <- ldply(seq_along(lines), function(i) {
     df <- fortify(lines[[i]])
     df$piece <- i
     df
