@@ -1,6 +1,36 @@
+#' Connect observations by stairs.
+#'
+#' @inheritParams geom_point
+#' @param direction direction of stairs: 'vh' for vertical then horizontal, or
+#'   'hv' for horizontal then vertical
+#' @export
+#' @examples
+#' # Simple quantiles/ECDF from examples(plot)
+#' x <- sort(rnorm(47))
+#' qplot(seq_along(x), x, geom="step")
+#' 
+#' # Steps go horizontally, then vertically (default)
+#' qplot(seq_along(x), x, geom="step", direction = "hv")
+#' plot(x, type = "s")
+#' # Steps go vertically, then horizontally
+#' qplot(seq_along(x), x, geom="step", direction = "vh")
+#' plot(x, type = "S")
+#' 
+#' # Also works with other aesthetics
+#' df <- data.frame(
+#'   x = sort(rnorm(50)),
+#'   trt = sample(c("a", "b"), 50, rep = TRUE)
+#' )
+#' qplot(seq_along(x), x, data = df, geom="step", colour = trt)
+geom_step <- function (mapping = NULL, data = NULL, stat = "identity", position = "identity", 
+direction = "hv", ...) {
+  GeomStep$new(mapping = mapping, data = data, stat = stat, position = position, 
+  direction = direction, ...)
+}
+
 GeomStep <- proto(Geom, {
   objname <- "step"
-  desc <- "Connect observations by stairs"
+
   icon <- function(.) {
     n <- 15
     xs <- rep(0:n, each = 2)[-2*(n + 1)] / 15
@@ -18,31 +48,7 @@ GeomStep <- proto(Geom, {
   }
   guide_geom <- function(.) "path"
 
-  desc_params <- list(
-    direction = "direction of stairs: 'vh' for vertical then horizontal, or 'hv' for horizontal then vertical"
-  )
   default_stat <- function(.) StatIdentity
-  
-  examples <- function(.) {
-    # Simple quantiles/ECDF from examples(plot)
-    x <- sort(rnorm(47))
-    qplot(seq_along(x), x, geom="step")
-    
-    # Steps go horizontally, then vertically (default)
-    qplot(seq_along(x), x, geom="step", direction = "hv")
-    plot(x, type = "s")
-    # Steps go vertically, then horizontally
-    qplot(seq_along(x), x, geom="step", direction = "vh")
-    plot(x, type = "S")
-    
-    # Also works with other aesthetics
-    df <- data.frame(
-      x = sort(rnorm(50)),
-      trt = sample(c("a", "b"), 50, rep = T)
-    )
-    qplot(seq_along(x), x, data = df, geom="step", colour = trt)
-    
-  }
 })
 
 
