@@ -1,36 +1,30 @@
-# Draw a grid
-# Produce a grob to be used as a background in panels
-# 
-# @arguments theme to use to draw elements
-# @arguments minor breaks in x axis
-# @arguments major breaks in x axis
-# @arguments minor breaks in y axis
-# @arguments major breaks in y axis
-# @keyword internal
+# Produce a grob to be used as for panel backgrounds
 guide_grid <- function(theme, x.minor, x.major, y.minor, y.major) {
+  
+  x.minor <- setdiff(x.minor, x.major)
+  y.minor <- setdiff(y.minor, y.major)
+  
   ggname("grill", grobTree(
     theme_render(theme, "panel.background"),
-    
-    theme_render(
+    if(length(y.minor) > 0) theme_render(
       theme, "panel.grid.minor", name = "y",
       x = rep(0:1, length(y.minor)), y = rep(y.minor, each=2), 
       id.lengths = rep(2, length(y.minor))
     ),
-    theme_render(
+    if(length(x.minor) > 0) theme_render(
       theme, "panel.grid.minor", name = "x", 
       x = rep(x.minor, each=2), y = rep(0:1, length(x.minor)),
       id.lengths = rep(2, length(x.minor))
     ),
-
-    theme_render(
+    if(length(y.major) > 0) theme_render(
       theme, "panel.grid.major", name = "y",
       x = rep(0:1, length(y.major)), y = rep(y.major, each=2), 
       id.lengths = rep(2, length(y.major))
     ),
-    theme_render(
+    if(length(x.major) > 0) theme_render(
       theme, "panel.grid.major", name = "x", 
       x = rep(x.major, each=2), y = rep(0:1, length(x.major)), 
       id.lengths = rep(2, length(x.major))
     )
   ))
-}
\ No newline at end of file
+}
