@@ -1,9 +1,5 @@
-# Collide
-# Detect and prevent collisions
-# 
-# Powers dodging, stacking and filling
-# 
-# @keyword internal
+# Detect and prevent collisions.
+# Powers dodging, stacking and filling.
 collide <- function(data, width = NULL, name, strategy, check.width = TRUE) {
   # Determine width
   if (!is.null(width)) {
@@ -23,19 +19,22 @@ collide <- function(data, width = NULL, name, strategy, check.width = TRUE) {
     # Width determined from data, must be floating point constant 
     widths <- unique(with(data, xmax - xmin))
     widths <- widths[!is.na(widths)]
-    if (check.width && length(widths) > 1 && sd(widths) > 1e-6) {
-      stop(name, " requires constant width", call. = FALSE)
+    if (!zero_range(range(widths))) {
+      warning(name, " requires constant width: output may be incorrect", 
+        call. = FALSE)
     }
     width <- widths[1]
   }
 
-  # Reorder by x position, preserving order of group
-  data <- data[order(data$xmin, data$group), ]
+  # Reorder by x position, relying on stable sort to preserve existing 
+  # ordering, which may be by group or order.
+  data <- data[order(data$xmin), ]
 
   # Check for overlap
   intervals <- as.numeric(t(unique(data[c("xmin", "xmax")])))
-  intervals <- scale(intervals[!is.na(intervals)])
-  if (any(diff(intervals) < -1e-6)) {
+  intervals <- intervals[!is.na(intervals)]
+  
+  if (length(unique(intervals)) > 1 & any(diff(scale(intervals)) < -1e-6)) {
     warning(name, " requires non-overlapping x intervals", call. = FALSE)
     # This is where the algorithm from [L. Wilkinson. Dot plots. 
     # The American Statistician, 1999.] should be used
@@ -54,40 +53,40 @@ collide <- function(data, width = NULL, name, strategy, check.width = TRUE) {
   }
 }
 
-# Stack overlapping intervals
+# Stack overlapping intervals.
 # Assumes that each set has the same horizontal position
-# 
-# @keyword internal
 pos_stack <- function(df, width) {
   if (nrow(df) == 1) return(df)
   
   n <- nrow(df) + 1
   y <- with(df, ifelse(is.na(y), 0, y))
-  heights <- c(0, cumsum(y))
+  if (all(is.na(df$x))) {
+    heights <- rep(NA, n)
+  } else {
+    heights <- c(0, cumsum(y))
+  }
 
   within(df, {
     ymin <- heights[-n]
     ymax <- heights[-1]
+    y <- ymax
   })
 }
 
-# Stack overlapping intervals and set height to 1
-# Assumes that each set has the same horizontal position
-# 
-# @keyword internal
+# Stack overlapping intervals and set height to 1.
+# Assumes that each set has the same horizontal position.
 pos_fill <- function(df, width) {
   within(pos_stack(df, width), {
     ymin <- ymin / max(ymax)
     ymax <- ymax / max(ymax)
+    y <- ymax
   })
 }
 
-# Dodge overlapping interval
-# Assumes that each set has the same horizontal position
-# 
-# @keyword internal
+# Dodge overlapping interval.
+# Assumes that each set has the same horizontal position.
 pos_dodge <- function(df, width) {
-  n <- nrow(df)
+  n <- length(unique(df$group))
   if (n == 1) return(df)
   
   if (!all(c("xmin", "xmax") %in% names(df))) {
@@ -101,9 +100,13 @@ pos_dodge <- function(df, width) {
   # df <- data.frame(n = c(2:5, 10, 26), div = c(4, 3, 2.666666,  2.5, 2.2, 2.1))
   # qplot(n, div, data = df)
   
+  # Have a new group index from 1 to number of groups.
+  # This might be needed if the group numbers in this set don't include all of 1:n
+  groupidx <- match(df$group, sort(unique(df$group)))
+
   within(df, {
-    xmin <- xmin + width / n * (seq_len(n) - 1) - diff * (n - 1) / (2 * n)
+    xmin <- xmin + width / n * (groupidx - 1) - diff * (n - 1) / (2 * n)
     xmax <- xmin + d_width / n
     x <- (xmin + xmax) / 2
   })
-}
\ No newline at end of file
+}
