@@ -1,7 +1,79 @@
-# Bin data
-# This function powers \code{\link{stat_bin}}
-#
-# @keyword internal
+#' Bin data.
+#' 
+#' Missing values are currently silently dropped.
+#'
+#' @inheritParams stat_identity
+#' @param binwidth Bin width to use. Defaults to 1/30 of the range of the
+#'   data
+#' @param breaks Actual breaks to use.  Overrides bin width and origin 
+#' @param origin Origin of first bin 
+#' @param width Width of bars when used with categorical data 
+#' @param right If \code{TRUE}, right-closed, left-open, if \code{FALSE}, 
+#"   the default, right-open, left-closed.
+#' @param drop If TRUE, remove all bins with zero counts
+#' @return New data frame with additional columns:
+#'   \item{count}{number of points in bin}
+#'   \item{density}{density of points in bin, scaled to integrate to 1}
+#'   \item{ncount}{count, scaled to maximum of 1}
+#'   \item{ndensity}{density, scaled to maximum of 1}
+#' @export
+#' @examples
+#' \donttest{
+#' simple <- data.frame(x = rep(1:10, each = 2))
+#' base <- ggplot(simple, aes(x))
+#' # By default, right = TRUE, and intervals are of the form (a, b]
+#' base + stat_bin(binwidth = 1, drop = FALSE, right = TRUE, col = "black")
+#' # If right = FALSE intervals are of the form [a, b)
+#' base + stat_bin(binwidth = 1, drop = FALSE, right = FALSE, col = "black")
+#' 
+#' m <- ggplot(movies, aes(x=rating))
+#' m + stat_bin()
+#' m + stat_bin(binwidth=0.1)
+#' m + stat_bin(breaks=seq(4,6, by=0.1))
+#' # See geom_histogram for more histogram examples
+#' 
+#' # To create a unit area histogram, use aes(y = ..density..)
+#' (linehist <- m + stat_bin(aes(y = ..density..), binwidth=0.1,
+#'   geom="line", position="identity"))
+#' linehist + stat_density(colour="blue", fill=NA)
+#' 
+#' # Also works with categorical variables
+#' ggplot(movies, aes(x=mpaa)) + stat_bin()
+#' qplot(mpaa, data=movies, stat="bin")
+#' }
+stat_bin <- function (mapping = NULL, data = NULL, geom = "bar", position = "stack", 
+width = 0.9, drop = FALSE, right = FALSE, binwidth = NULL, origin = NULL, breaks = NULL, ...) { 
+  StatBin$new(mapping = mapping, data = data, geom = geom, position = position, 
+  width = width, drop = drop, right = right, binwidth = binwidth, origin = origin, breaks = breaks, ...)
+}
+
+StatBin <- proto(Stat, {
+  objname <- "bin"
+  informed <- FALSE
+  
+  calculate_groups <- function(., data, ...) {
+    .$informed <- FALSE
+    .super$calculate_groups(., data, ...)
+  }
+  
+  calculate <- function(., data, scales, binwidth=NULL, origin=NULL, breaks=NULL, width=0.9, drop = FALSE, right = FALSE, ...) {
+    range <- scale_dimension(scales$x)
+
+    if (is.null(breaks) && is.null(binwidth) && !is.integer(data$x) && !.$informed) {
+      message("stat_bin: binwidth defaulted to range/30. Use 'binwidth = x' to adjust this.")
+      .$informed <- TRUE
+    }
+    
+    bin(data$x, data$weight, binwidth=binwidth, origin=origin, breaks=breaks, range=range, width=width, drop = drop, right = right)
+  }
+
+  icon <- function(.) GeomHistogram$icon()
+  default_aes <- function(.) aes(y = ..count..)
+  required_aes <- c("x")
+  default_geom <- function(.) GeomBar
+  
+})
+
 bin <- function(x, weight=NULL, binwidth=NULL, origin=NULL, breaks=NULL, range=NULL, width=0.9, drop = FALSE, right = TRUE) {
   
   if (length(na.omit(x)) == 0) return(data.frame())
@@ -67,8 +139,8 @@ bin <- function(x, weight=NULL, binwidth=NULL, origin=NULL, breaks=NULL, range=N
 # Generate sequence of fixed size intervals covering range
 # All locations are multiples of size
 # 
-# @arguments range
-# @arguments interval size
+# @param range
+# @param interval size
 # @keyword internal
 # @seealso \code{\link{reshape}{round_any}}
 fullseq <- function(range, size, pad = FALSE) {
@@ -90,71 +162,3 @@ fullseq <- function(range, size, pad = FALSE) {
   
 }
 
-StatBin <- proto(Stat, {
-  informed <- FALSE
-  
-  calculate_groups <- function(., data, ...) {
-    .$informed <- FALSE
-    .super$calculate_groups(., data, ...)
-  }
-  
-  calculate <- function(., data, scales, binwidth=NULL, origin=NULL, breaks=NULL, width=0.9, drop = FALSE, right = TRUE, ...) {
-    range <- scales$x$output_set()
-
-    if (is.null(breaks) && is.null(binwidth) && !is.integer(data$x) && !.$informed) {
-      message("stat_bin: binwidth defaulted to range/30. Use 'binwidth = x' to adjust this.")
-      .$informed <- TRUE
-    }
-    
-    bin(data$x, data$weight, binwidth=binwidth, origin=origin, breaks=breaks, range=range, width=width, drop = drop, right = right)
-  }
-
-  objname <- "bin" 
-  desc <- "Bin data"
-  icon <- function(.) GeomHistogram$icon()
-  desc_params <- list(
-    binwidth = "Bin width to use. Defaults to 1/30 of the range of the data.",
-    breaks = "Actual breaks to use.  Overrides bin width and origin",
-    origin = "Origin of first bin",
-    width = "Width of bars when used with categorical data",
-    right = "Should intervals be closed on the right (a, b], or not [a, b)",
-    drop = "If TRUE, remove all bins with zero counts"
-  )
-  desc_outputs <- list(
-    count = "number of points in bin",
-    density = "density of points in bin, scaled to integrate to 1",
-    ncount = "count, scaled to maximum of 1",
-    ndensity = "density, scaled to maximum of 1"
-  )
-  details <- "<p>Missing values are currently silently dropped.</p>"
-  
-  default_aes <- function(.) aes(y = ..count..)
-  required_aes <- c("x")
-  default_geom <- function(.) GeomBar
-  
-  examples <- function(.) {
-    simple <- data.frame(x = rep(1:10, each = 2))
-    base <- ggplot(simple, aes(x))
-    # By default, right = TRUE, and intervals are of the form (a, b]
-    base + stat_bin(binwidth = 1, drop = FALSE, right = TRUE, col = "black")
-    # If right = FALSE intervals are of the form [a, b)
-    base + stat_bin(binwidth = 1, drop = FALSE, right = FALSE, col = "black")
-    
-    m <- ggplot(movies, aes(x=rating))
-    m + stat_bin()
-    m + stat_bin(binwidth=0.1)
-    m + stat_bin(breaks=seq(4,6, by=0.1))
-    # See geom_histogram for more histogram examples
-    
-    # To create a unit area histogram, use aes(y = ..density..)
-    (linehist <- m + stat_bin(aes(y = ..density..), binwidth=0.1,
-      geom="line", position="identity"))
-    linehist + stat_density(colour="blue", fill=NA)
-    
-    # Also works with categorical variables
-    ggplot(movies, aes(x=mpaa)) + stat_bin()
-    qplot(mpaa, data=movies, stat="bin")
-    
-  }
-  
-})
